@@ -111,7 +111,7 @@ download_plink2 <- function(dir = tempdir(), AVX2 = TRUE, ARM = FALSE, AMD = FAL
   plink.names <- get_pattern(
     x = readLines("https://www.cog-genomics.org/plink/2.0/"),
     # http://s3.amazonaws.com/plink2-assets/plink2_linux_avx2_20190527.zip
-    pattern = ".*(http[s]*://s3.amazonaws.com/plink2-assets/plink2_.+?\\.zip).*"
+    pattern = ".*(http[s]*://s3.amazonaws.com/plink2-assets/.*?plink2_.+?\\.zip).*"
   )
   plink.builds <- data.frame(
     url  = sub("^http://", "https://", plink.names),
