@@ -30,7 +30,7 @@ expect_s4_class(test3$genotypes, "FBM.code256")
 
 rds2bk <- function(rdsfile) sub("\\.rds$", ".bk", rdsfile)
 
-rdsfile0 <- system.file("testdata", "before_readonly.rds", package = "bigsnpr")
+rdsfile0 <- test_path("testdata", "before_readonly.rds")
 rdsfile <- tempfile(fileext = ".rds")
 file.copy(from = rdsfile0, to = rdsfile)
 file.copy(from = rds2bk(rdsfile0), to = rds2bk(rdsfile))
