@@ -151,7 +151,7 @@ test_that("bed_cor() works like snp_cor()", {
   obj_bed <- bed(bedfile)
   alpha <- runif(1)
   expect_error(bed_cor(obj.bed = G, alpha = alpha),
-               "'obj.bed' is not of class 'bed'.", fixed = TRUE)
+               "'obj.bed' is not of class 'bed' or 'bed_light'.", fixed = TRUE)
   expect_equal(
     snp_cor(Gna = G, alpha = alpha),
     bed_cor(obj.bed = obj_bed, alpha = alpha)
